Crate rust_gnc

Crate rust_gnc 

Rust GNC

A high-performance, no_std Guidance, Navigation, and Control library designed for unmanned aerial vehicles.

Re-exports

pub use units::angular::Radians;
pub use units::spatial::Attitude;
pub use units::spatial::Position;
pub use units::spatial::Velocity;

Modules

control
Flight control laws ranging from PID loops to LQR and Sliding Mode Control.
filters
Signal processing tools including Complementary, Kalman, and Notch filters.
navigation
Global and local coordinate estimation and GPS fusion logic.
telemetry
High-speed binary logging for post-flight analysis.
units
Physical unit abstractions to ensure type-safety (e.g., preventing Degrees vs Radians errors).